Holy crap!
My new CopyRect method is 20x faster than the old method!
Now instead of taking two seconds to scale an image from 1024x1024 to 2048x2048, it takes one TENTH of a second!
Woot!
I just wish I'd tried this three days ago when I first considered it instead of spending all this time screwing around with GDI commands! ARGH!!!!!
Oh and I should mention that I'm pretty sure I could make this new method scale to ANY scale, without any speed hit.
In other words, my Zoom function, coded in Blitz, should ultimately end up being able to do what the ScaleImage command does with TFormFilter False enabled, not 10, not 20, not 30, but, EIGHTY TIMES faster!
(And it occurs to me that someone else may have already done this in a code archives entry somewhere.)
My new CopyRect method is 20x faster than the old method!
Now instead of taking two seconds to scale an image from 1024x1024 to 2048x2048, it takes one TENTH of a second!
Woot!
I just wish I'd tried this three days ago when I first considered it instead of spending all this time screwing around with GDI commands! ARGH!!!!!
Oh and I should mention that I'm pretty sure I could make this new method scale to ANY scale, without any speed hit.
In other words, my Zoom function, coded in Blitz, should ultimately end up being able to do what the ScaleImage command does with TFormFilter False enabled, not 10, not 20, not 30, but, EIGHTY TIMES faster!
(And it occurs to me that someone else may have already done this in a code archives entry somewhere.)